package hdl

import (
	"applet/app/admin/lib/validate"
	"applet/app/admin/md"
	"applet/app/admin/svc"
	svc2 "applet/app/admin/svc/enterprise_manage"
	"applet/app/db"
	"applet/app/db/model"
	"applet/app/e"
	"applet/app/enum"
	"applet/app/utils"
	"applet/app/utils/cache"
	"fmt"
	"github.com/360EntSecGroup-Skylar/excelize"
	"github.com/gin-gonic/gin"
	"strconv"
	"time"
)

func CentralKitchenForSchoolUserUpdate(c *gin.Context) {
	var req md.CentralKitchenForSchoolUserUpdateReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	err = svc2.CentralKitchenForSchoolUserUpdate(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func CentralKitchenForSchoolUserDelete(c *gin.Context) {
	var req md.CentralKitchenForSchoolUserDeleteReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	err = svc2.CentralKitchenForSchoolUserDelete(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func CentralKitchenForSchoolStudentList(c *gin.Context) {
	var req md.CentralKitchenForSchoolStudentListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	resp, total, err := svc2.CentralKitchenForSchoolStudentList(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":  resp,
		"total": total,
		"admission_list": []map[string]string{
			{
				"name":  "按班级",
				"value": "admission_type_by_class",
			},
			{
				"name":  "按年级",
				"value": "admission_type_by_grade",
			},
		},
		"user_identity_cert_type_list": []map[string]interface{}{
			{
				"name":  enum.UserIdentityCertType.String(enum.UserIdentityCertTypeForIdCard),
				"value": enum.UserIdentityCertTypeForIdCard,
			},
			{
				"name":  enum.UserIdentityCertType.String(enum.UserIdentityCertTypeForStudentId),
				"value": enum.UserIdentityCertTypeForStudentId,
			},
			//{
			//	"name":  enum.UserIdentityCertType.String(enum.UserIdentityCertTypeForPassport),
			//	"value": enum.UserIdentityCertTypeForPassport,
			//},
		},
	}, nil)
	return
}

func CentralKitchenForSchoolTeacherList(c *gin.Context) {
	var req md.CentralKitchenForSchoolTeacherListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	resp, total, err := svc2.CentralKitchenForSchoolTeacherList(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":  resp,
		"total": total,
		"user_identity_cert_type_list": []map[string]interface{}{
			{
				"name":  enum.UserIdentityCertType.String(enum.UserIdentityCertTypeForIdCard),
				"value": enum.UserIdentityCertTypeForIdCard,
			},
			{
				"name":  enum.UserIdentityCertType.String(enum.UserIdentityCertTypeForStudentId),
				"value": enum.UserIdentityCertTypeForStudentId,
			},
			//{
			//	"name":  enum.UserIdentityCertType.String(enum.UserIdentityCertTypeForPassport),
			//	"value": enum.UserIdentityCertTypeForPassport,
			//},
		},
	}, nil)
	return
}

func CentralKitchenForSchoolTeacherUpdate(c *gin.Context) {
	var req md.CentralKitchenForSchoolTeacherUpdateReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	userIdentityDb := db.UserIdentityDb{}
	userIdentityDb.Set(0)
	userIdentity, err := userIdentityDb.GetUserIdentity(req.UserIdentityId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if userIdentity == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}
	userIdentity.IdNo = req.IdNo
	userIdentity.Name = req.Name
	userIdentity.CertType = req.CertType
	_, err = userIdentityDb.UserIdentityUpdate(req.UserIdentityId, userIdentity, "id_no", "name", "cert_type")
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func CentralKitchenForSchoolStudentUpdate(c *gin.Context) {
	var req md.CentralKitchenForSchoolStudentUpdateReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	err = svc2.CentralKitchenForSchoolStudentUpdate(req)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	e.OutSuc(c, "success", nil)
	return
}

func CentralKitchenForSchoolStudentAdmission(c *gin.Context) {
	var req md.CentralKitchenForSchoolStudentAdmissionReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	err = svc2.CentralKitchenForSchoolStudentAdmission(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func CentralKitchenForSchoolBatchStudentAdmission(c *gin.Context) {
	Kind := c.DefaultQuery("kind", "1")
	switch Kind {
	case "1":
		//按学校
		var req md.CentralKitchenForSchoolStudentAdmissionBySchool
		err := c.ShouldBindJSON(&req)
		if err != nil {
			err = validate.HandleValidateErr(err)
			err1 := err.(e.E)
			e.OutErr(c, err1.Code, err1.Error())
			return
		}
		err = svc2.CentralKitchenForSchoolStudentAdmissionBySchool(req)
		if err != nil {
			e.OutErr(c, e.ERR, err.Error())
			return
		}
		break
	case "2":
		//按年级
		var req md.CentralKitchenForSchoolStudentAdmissionByGrade
		err := c.ShouldBindJSON(&req)
		if err != nil {
			err = validate.HandleValidateErr(err)
			err1 := err.(e.E)
			e.OutErr(c, err1.Code, err1.Error())
			return
		}
		err = svc2.CentralKitchenForSchoolStudentAdmissionByGrade(req)
		if err != nil {
			e.OutErr(c, e.ERR, err.Error())
			return
		}
		break
	case "3":
		//按班级
		var req md.CentralKitchenForSchoolStudentAdmissionByClass
		err := c.ShouldBindJSON(&req)
		if err != nil {
			err = validate.HandleValidateErr(err)
			err1 := err.(e.E)
			e.OutErr(c, err1.Code, err1.Error())
			return
		}
		err = svc2.CentralKitchenForSchoolStudentAdmissionByClass(req)
		if err != nil {
			e.OutErr(c, e.ERR, err.Error())
			return
		}
		break
	}
	e.OutSuc(c, "success", nil)
	return
}

func CentralKitchenForSchoolStudentDelete(c *gin.Context) {
	var req md.CentralKitchenForSchoolStudentDeleteReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	err = svc2.CentralKitchenForSchoolStudentDelete(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func CentralKitchenForSchoolTeacherDelete(c *gin.Context) {
	var req md.CentralKitchenForSchoolTeacherDeleteReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	//删除 user_identity
	_, err = db.Db.Where("enterprise_id =?", req.EnterpriseId).In("id", req.UserIdentityIds).Delete(model.UserIdentity{})
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	e.OutSuc(c, "success", nil)
	return
}

func GetCentralKitchenForSchoolWithSpecByTeacher(c *gin.Context) {
	enterpriseId := utils.StrToInt(c.DefaultQuery("enterprise_id", "0"))
	centralKitchenForSchoolWithSpec := db.CentralKitchenForSchoolWithSpec{}
	centralKitchenForSchoolWithSpec.Set(enterpriseId)
	data, err := centralKitchenForSchoolWithSpec.GetCentralKitchenForSchoolWithSpec()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	e.OutSuc(c, map[string]interface{}{
		"data": data,
	}, nil)
	return
}

func SetCentralKitchenForSchoolWithSpecByTeacher(c *gin.Context) {
	var req md.SetCentralKitchenForSchoolWithSpecReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	centralKitchenForSchoolWithSpec := db.CentralKitchenForSchoolWithSpec{}
	centralKitchenForSchoolWithSpec.Set(req.EnterpriseId)

	spec, err := centralKitchenForSchoolWithSpec.GetCentralKitchenForSchoolWithSpec()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	_, err = centralKitchenForSchoolWithSpec.CentralKitchenForSchoolWithSpecDelete()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	now := time.Now()
	if spec != nil {
		insertConfirm, err1 := centralKitchenForSchoolWithSpec.CentralKitchenForSchoolWithSpecInsert(&model.CentralKitchenForSchoolWithSpec{
			IsOpenBreakfast:              spec.IsOpenBreakfast,
			IsOpenLunch:                  spec.IsOpenLunch,
			IsOpenDinner:                 spec.IsOpenDinner,
			IsOpenBreakfastForTeacher:    spec.IsOpenBreakfastForTeacher,
			IsOpenLunchForTeacher:        spec.IsOpenLunchForTeacher,
			IsOpenDinnerForTeacher:       spec.IsOpenDinnerForTeacher,
			EnterpriseId:                 req.EnterpriseId,
			BreakfastUnitPrice:           req.BreakfastUnitPrice,
			LunchUnitPrice:               req.LunchUnitPrice,
			DinnerUnitPrice:              req.DinnerUnitPrice,
			BreakfastUnitPriceForTeacher: req.BreakfastUnitPriceForTeacher,
			LunchUnitPriceForTeacher:     req.LunchUnitPriceForTeacher,
			DinnerUnitPriceForTeacher:    req.DinnerUnitPriceForTeacher,
			BreakfastTeacherNotice:       req.BreakfastTeacherNotice,
			LunchTeacherNotice:           req.LunchTeacherNotice,
			DinnerTeacherNotice:          req.DinnerTeacherNotice,
			CreateAt:                     now.Format("2006-01-02 15:04:05"),
			UpdateAt:                     now.Format("2006-01-02 15:04:05"),
		})
		if err1 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err1.Error())
			return
		}
		if insertConfirm <= 0 {
			e.OutErr(c, e.ERR_DB_ORM, "新增数据失败")
			return
		}
	} else {
		insertConfirm, err1 := centralKitchenForSchoolWithSpec.CentralKitchenForSchoolWithSpecInsert(&model.CentralKitchenForSchoolWithSpec{
			EnterpriseId:                 req.EnterpriseId,
			BreakfastUnitPrice:           req.BreakfastUnitPrice,
			LunchUnitPrice:               req.LunchUnitPrice,
			DinnerUnitPrice:              req.DinnerUnitPrice,
			BreakfastUnitPriceForTeacher: req.BreakfastUnitPriceForTeacher,
			LunchUnitPriceForTeacher:     req.LunchUnitPriceForTeacher,
			DinnerUnitPriceForTeacher:    req.DinnerUnitPriceForTeacher,
			BreakfastTeacherNotice:       req.BreakfastTeacherNotice,
			LunchTeacherNotice:           req.LunchTeacherNotice,
			DinnerTeacherNotice:          req.DinnerTeacherNotice,
			CreateAt:                     now.Format("2006-01-02 15:04:05"),
			UpdateAt:                     now.Format("2006-01-02 15:04:05"),
		})
		if err1 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err1.Error())
			return
		}
		if insertConfirm <= 0 {
			e.OutErr(c, e.ERR_DB_ORM, "新增数据失败")
			return
		}
	}

	e.OutSuc(c, "success", nil)
	return
}

func SetCentralKitchenForSchoolWithSpecByPeriod(c *gin.Context) {
	var req md.SetCentralKitchenForSchoolWithSpecByPeriodReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	for _, v := range req.List {
		periodDb := db.PeriodDb{}
		periodDb.Set(req.EnterpriseId)
		period, err1 := periodDb.GetPeriod(v.PeriodId)
		if err1 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err1.Error())
			return
		}
		period.BreakfastUnitPrice = v.BreakfastUnitPrice
		period.LunchUnitPrice = v.LunchUnitPrice
		period.DinnerUnitPrice = v.DinnerUnitPrice
		_, err2 := periodDb.PeriodUpdate(period, "breakfast_unit_price", "lunch_unit_price", "dinner_unit_price")
		if err2 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err2.Error())
			return
		}
	}

	e.OutSuc(c, "success", nil)
	return
}

func SetCentralKitchenForSchoolWithSpecByMealLabel(c *gin.Context) {
	var req md.SetCentralKitchenForSchoolWithSpecByMealLabel
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	now := time.Now()
	mealLabelDb := db.MealLabelDb{}
	mealLabelDb.Set(req.EnterpriseId)
	labels, err := mealLabelDb.FindMealLabel(req.GradeId, req.Kind)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	var nowIds = map[int]bool{}
	for _, v := range req.MealLabelList {
		if v.Id != 0 {
			mealLabel, err := mealLabelDb.GetMealLabel(v.Id)
			if err != nil {
				e.OutErr(c, e.ERR_DB_ORM, err.Error())
				return
			}
			mealLabel.Name = v.Name
			mealLabel.Price = v.Price
			_, err = mealLabelDb.MealLabelUpdate(mealLabel, "name", "price")
			if err != nil {
				e.OutErr(c, e.ERR_DB_ORM, err.Error())
				return
			}
			nowIds[v.Id] = true
		} else {
			mealLabel := &model.MealLabel{
				Name:         v.Name,
				EnterpriseId: req.EnterpriseId,
				GradeId:      req.GradeId,
				Kind:         req.Kind,
				Price:        v.Price,
				CreateAt:     now.Format("2006-01-02 15:04:05"),
				UpdateAt:     now.Format("2006-01-02 15:04:05"),
			}
			_, err = mealLabelDb.MealLabelInsert(mealLabel)
			if err != nil {
				e.OutErr(c, e.ERR_DB_ORM, err.Error())
				return
			}
		}
	}

	var needDelIds []int
	for _, v := range *labels {
		if !nowIds[v.Id] {
			needDelIds = append(needDelIds, v.Id)
		}
	}
	if len(needDelIds) > 0 {
		_, err = mealLabelDb.MealLabelDelete(needDelIds)
		if err != nil {
			e.OutErr(c, e.ERR_DB_ORM, err.Error())
			return
		}
	}

	e.OutSuc(c, "success", nil)
	return
}

func GetCentralKitchenForSchoolWithSpecByMealLabel(c *gin.Context) {
	var req md.GetCentralKitchenForSchoolWithSpecByMealLabelReq
	if req.Kind == 0 {
		req.Kind = 1 //TODO::默认查询早餐
	}
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	var resp = md.GetCentralKitchenForSchoolWithSpecByMealLabelResp{}
	resp.EnterpriseId = req.EnterpriseId
	resp.Kind = req.Kind

	gradeList, total, err := svc2.SelfSupportForSchoolGradeList(md.SelfSupportForSchoolGradeListReq{
		EnterpriseId: req.EnterpriseId,
		Limit:        req.Limit,
		Page:         req.Page,
		Name:         "",
	})
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}

	mealLabelDb := db.MealLabelDb{}
	mealLabelDb.Set(resp.EnterpriseId)
	for _, v := range gradeList {
		mealLabels, err := mealLabelDb.FindMealLabel(v.Id, req.Kind)
		if err != nil {
			e.OutErr(c, e.ERR_DB_ORM, err.Error())
			return
		}
		var mealLabelList []md.MealLabelList
		for _, vv := range *mealLabels {
			mealLabelList = append(mealLabelList, md.MealLabelList{
				Id:    vv.Id,
				Name:  vv.Name,
				Price: vv.Price,
			})
		}

		resp.List = append(resp.List, struct {
			GradeId       int                `json:"grade_id" binding:"required" label:"年级id"`
			Name          string             `json:"name" label:"年级名称"`
			MealLabelList []md.MealLabelList `json:"meal_label_list" label:"餐标集合"`
		}{
			GradeId:       v.Id,
			Name:          v.Name,
			MealLabelList: mealLabelList,
		})
	}

	e.OutSuc(c, map[string]interface{}{
		"list":  resp,
		"total": total,
	}, nil)
	return
}

func ListCentralKitchenForSchoolPackage(c *gin.Context) {
	var req md.ListCentralKitchenForSchoolPackageReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	centralKitchenForSchoolPackageDb := db.CentralKitchenForSchoolPackageDb{}
	centralKitchenForSchoolPackageDb.Set()
	list, total, err := centralKitchenForSchoolPackageDb.CentralKitchenForSchoolPackageList(req)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":  list,
		"total": total,
		"state_list": []map[string]interface{}{
			{
				"name":  "可用",
				"value": 1,
			},
			{
				"name":  "不可用",
				"value": 2,
			},
		},
	}, nil)
	return
}

func DetailCentralKitchenForSchoolPackage(c *gin.Context) {
	packageId := utils.StrToInt(c.DefaultQuery("package_id", ""))
	centralKitchenForSchoolPackageDb := db.CentralKitchenForSchoolPackageDb{}
	centralKitchenForSchoolPackageDb.Set()
	centralKitchenForSchoolPackage, err := centralKitchenForSchoolPackageDb.GetCentralKitchenForSchoolPackage(packageId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if centralKitchenForSchoolPackage == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	centralKitchenForSchoolPackageWithDayDb := db.CentralKitchenForSchoolPackageWithDayDb{}
	centralKitchenForSchoolPackageWithDayDb.Set(packageId)
	centralKitchenForSchoolPackageWithDay, err := centralKitchenForSchoolPackageWithDayDb.FindCentralKitchenForSchoolPackageWithDay()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	var resp = md.SaveCentralKitchenForSchoolPackageReq{
		PackageId:    centralKitchenForSchoolPackage.Id,
		EnterpriseId: centralKitchenForSchoolPackage.EnterpriseId,
		Year:         centralKitchenForSchoolPackage.Year,
		Month:        centralKitchenForSchoolPackage.Month,
		StartDate:    centralKitchenForSchoolPackage.StartDate,
		EndDate:      centralKitchenForSchoolPackage.EndDate,
		DateList:     nil,
	}
	for _, v := range *centralKitchenForSchoolPackageWithDay {
		resp.DateList = append(resp.DateList, struct {
			Date            string `json:"date"`
			IsOpenBreakfast int32  `json:"is_open_breakfast"`
			IsOpenLunch     int32  `json:"is_open_lunch"`
			IsOpenDinner    int32  `json:"is_open_dinner"`
			IsOpenReplenish int32  `json:"is_open_replenish"`
		}{Date: v.Date, IsOpenBreakfast: int32(v.IsOpenBreakfast), IsOpenLunch: int32(v.IsOpenLunch), IsOpenDinner: int32(v.IsOpenDinner), IsOpenReplenish: int32(v.IsOpenReplenish)})
	}
	e.OutSuc(c, resp, nil)
	return
}

func SaveCentralKitchenForSchoolPackage(c *gin.Context) {
	var req md.SaveCentralKitchenForSchoolPackageReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	//判断是新增 / 编辑
	if req.PackageId > 0 {
		err = svc.UpdateCentralKitchenForSchoolPackage(req)
		if err != nil {
			e.OutErr(c, e.ERR, err.Error())
			return
		}
	} else {
		err = svc.AddCentralKitchenForSchoolPackage(req)
		if err != nil {
			e.OutErr(c, e.ERR, err.Error())
			return
		}
	}
	e.OutSuc(c, "success", nil)
	return
}

func DeleteCentralKitchenForSchoolPackage(c *gin.Context) {
	packageId := c.Param("id")
	err := svc.DeleteCentralKitchenForSchoolPackage(utils.StrToInt(packageId))
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func SetBasicCentralKitchenForSchool(c *gin.Context) {
	var req md.SetBasicCentralKitchenForSchoolReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	now := time.Now()

	//1、更新 central_kitchen_for_school_set
	centralKitchenForSchoolSetDb := db.CentralKitchenForSchoolSetDb{}
	centralKitchenForSchoolSetDb.Set(req.EnterpriseId)
	set, err := centralKitchenForSchoolSetDb.GetCentralKitchenForSchoolSet()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if set != nil {
		set.IsOpenTeacherReportMeal = req.IsOpenTeacherReportMeal
		set.IsOpenReportMealForDay = req.IsOpenReportMealForDay
		set.IsOpenReportMealForMonth = req.IsOpenReportMealForMonth
		set.IsOpenReportMealForSemester = req.IsOpenReportMealForSemester
		set.IsOpenTeacherReportMealForDay = req.IsOpenTeacherReportMealForDay
		set.IsOpenTeacherReportMealForMonth = req.IsOpenTeacherReportMealForMonth
		set.IsOpenTeacherReportMealForSemester = req.IsOpenTeacherReportMealForSemester
		set.UpdateAt = now.Format("2006-01-02 15:04:05")
		_, err2 := centralKitchenForSchoolSetDb.CentralKitchenForSchoolSetUpdate(set.Id, set,
			"is_open_report_meal_for_day", "is_open_report_meal_for_month", "is_open_report_meal_for_semester",
			"is_open_teacher_report_meal", "is_open_teacher_report_meal_for_day", "is_open_teacher_report_meal_for_month", "is_open_teacher_report_meal_for_semester", "update_at")
		if err2 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err2.Error())
			return
		}
	} else {
		_, err2 := centralKitchenForSchoolSetDb.CentralKitchenForSchoolSetInsert(&model.CentralKitchenForSchoolSet{
			EnterpriseId:                       req.EnterpriseId,
			IsOpenTeacherReportMeal:            req.IsOpenTeacherReportMeal,
			IsOpenReportMealForDay:             req.IsOpenReportMealForDay,
			IsOpenReportMealForMonth:           req.IsOpenReportMealForMonth,
			IsOpenReportMealForSemester:        req.IsOpenReportMealForSemester,
			IsOpenTeacherReportMealForDay:      req.IsOpenTeacherReportMealForDay,
			IsOpenTeacherReportMealForMonth:    req.IsOpenTeacherReportMealForMonth,
			IsOpenTeacherReportMealForSemester: req.IsOpenTeacherReportMealForSemester,
			CreateAt:                           now.Format("2006-01-02 15:04:05"),
			UpdateAt:                           now.Format("2006-01-02 15:04:05"),
		})
		if err2 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err2.Error())
			return
		}
	}

	//2、更新 central_kitchen_for_school_with_spec
	centralKitchenForSchoolWithSpec := db.CentralKitchenForSchoolWithSpec{}
	centralKitchenForSchoolWithSpec.Set(req.EnterpriseId)
	spec, err := centralKitchenForSchoolWithSpec.GetCentralKitchenForSchoolWithSpec()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if spec != nil {
		spec.IsOpenBreakfast = req.IsOpenBreakfast
		spec.IsOpenLunch = req.IsOpenLunch
		spec.IsOpenDinner = req.IsOpenDinner
		spec.IsOpenBreakfastForTeacher = req.IsOpenBreakfastForTeacher
		spec.IsOpenLunchForTeacher = req.IsOpenLunchForTeacher
		spec.IsOpenDinnerForTeacher = req.IsOpenDinnerForTeacher
		spec.UpdateAt = now.Format("2006-01-02 15:04:05")
		_, err2 := centralKitchenForSchoolWithSpec.CentralKitchenForSchoolWithSpecUpdate(spec.Id, spec,
			"is_open_breakfast", "is_open_lunch", "is_open_dinner",
			"is_open_breakfast_for_teacher", "is_open_lunch_for_teacher", "is_open_dinner_for_teacher",
			"update_at")
		if err2 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err2.Error())
			return
		}
	} else {
		_, err2 := centralKitchenForSchoolWithSpec.CentralKitchenForSchoolWithSpecInsert(&model.CentralKitchenForSchoolWithSpec{
			EnterpriseId:              req.EnterpriseId,
			IsOpenBreakfast:           req.IsOpenBreakfast,
			IsOpenLunch:               req.IsOpenLunch,
			IsOpenDinner:              req.IsOpenDinner,
			IsOpenBreakfastForTeacher: req.IsOpenBreakfastForTeacher,
			IsOpenLunchForTeacher:     req.IsOpenLunchForTeacher,
			IsOpenDinnerForTeacher:    req.IsOpenDinnerForTeacher,
			CreateAt:                  now.Format("2006-01-02 15:04:05"),
			UpdateAt:                  now.Format("2006-01-02 15:04:05"),
		})
		if err2 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err2.Error())
			return
		}
	}

	//3、更新 `enterprise`
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}
	enterprise.Name = req.Name
	enterprise.State = req.State
	enterprise.UpdateAt = now.Format("2006-01-02 15:04:05")
	_, err = enterpriseDb.EnterpriseUpdate(enterprise, "name", "state", "update_at")
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	e.OutSuc(c, "success", nil)
	return
}

func GetBasicCentralKitchenForSchool(c *gin.Context) {
	enterpriseId := utils.StrToInt(c.DefaultQuery("enterprise_id", "0"))

	//1、获取 central_kitchen_for_school_set
	centralKitchenForSchoolSetDb := db.CentralKitchenForSchoolSetDb{}
	centralKitchenForSchoolSetDb.Set(enterpriseId)
	set, err := centralKitchenForSchoolSetDb.GetCentralKitchenForSchoolSet()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if set == nil {
		set = &model.CentralKitchenForSchoolSet{
			EnterpriseId:                       enterpriseId,
			IsOpenTeacherReportMeal:            1,
			IsOpenReportMealForDay:             1,
			IsOpenReportMealForMonth:           1,
			IsOpenReportMealForSemester:        1,
			IsOpenTeacherReportMealForDay:      1,
			IsOpenTeacherReportMealForMonth:    1,
			IsOpenTeacherReportMealForSemester: 1,
			CreateAt:                           time.Now().Format("2006-01-02 15:04:05"),
			UpdateAt:                           time.Now().Format("2006-01-02 15:04:05"),
		}
		_, err2 := centralKitchenForSchoolSetDb.CentralKitchenForSchoolSetInsert(set)
		if err2 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err2.Error())
			return
		}
	}

	//2、获取 central_kitchen_for_school_with_spec
	centralKitchenForSchoolWithSpec := db.CentralKitchenForSchoolWithSpec{}
	centralKitchenForSchoolWithSpec.Set(enterpriseId)
	spec, err := centralKitchenForSchoolWithSpec.GetCentralKitchenForSchoolWithSpec()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if spec == nil {
		spec = &model.CentralKitchenForSchoolWithSpec{
			EnterpriseId:                 enterpriseId,
			IsOpenBreakfast:              1,
			IsOpenLunch:                  1,
			IsOpenDinner:                 1,
			IsOpenBreakfastForTeacher:    1,
			IsOpenLunchForTeacher:        1,
			IsOpenDinnerForTeacher:       1,
			BreakfastUnitPrice:           "0",
			LunchUnitPrice:               "0",
			DinnerUnitPrice:              "0",
			BreakfastUnitPriceForTeacher: "0",
			LunchUnitPriceForTeacher:     "0",
			DinnerUnitPriceForTeacher:    "0",
			BreakfastTeacherNotice:       "",
			LunchTeacherNotice:           "",
			DinnerTeacherNotice:          "",
			CreateAt:                     time.Now().Format("2006-01-02 15:04:05"),
			UpdateAt:                     time.Now().Format("2006-01-02 15:04:05"),
		}
		_, err2 := centralKitchenForSchoolWithSpec.CentralKitchenForSchoolWithSpecInsert(spec)
		if err2 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err2.Error())
			return
		}
	}

	//3、更新 `enterprise`
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(enterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	e.OutSuc(c, map[string]interface{}{
		"central_kitchen_for_school_set":       set,
		"central_kitchen_for_school_with_spec": spec,
		"enterprise":                           enterprise,
	}, nil)
	return
}

func CentralKitchenForSchoolOrdList(c *gin.Context) {
	var req md.CentralKitchenForSchoolOrdListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	//enterpriseDb := db.EnterpriseDb{}
	//enterpriseDb.Set()
	//enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	//if err != nil {
	//	e.OutErr(c, e.ERR_DB_ORM, err.Error())
	//	return
	//}
	//if enterprise == nil {
	//	e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
	//	return
	//}

	resp, total, err := svc2.CentralKitchenForSchoolOrdList(c, req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}

	personNum, orderCountByDay, orderCountByMonth, orderCountByTerm, consumeAmount, err := svc2.CentralKitchenForSchoolOrdStatistics(c, req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}

	e.OutSuc(c, map[string]interface{}{
		"statistics": map[string]interface{}{
			"person_num":           personNum,
			"order_count_by_day":   orderCountByDay,
			"order_count_by_month": orderCountByMonth,
			"order_count_by_term":  orderCountByTerm,
			"consume_amount":       consumeAmount,
		},
		"list":                 resp,
		"total":                total,
		"enterprise_kind_list": md.EnterpriseKindForSchool,
		"kind_list": []map[string]string{
			{
				"name":  "按学期购买",
				"value": "1",
			},
			{
				"name":  "按月购买",
				"value": "2",
			},
			{
				"name":  "按天购买",
				"value": "3",
			},
			{
				"name":  "补餐",
				"value": "4",
			},
		},
		"pay_way_list": []map[string]interface{}{
			{
				"name":  "支付宝",
				"value": 1,
			},
			{
				"name":  "微信",
				"value": 2,
			},
		},
		"state_list": []map[string]interface{}{
			{
				"name":  enum.CentralKitchenForSchoolPackageOrdState.String(enum.CentralKitchenForSchoolPackageOrdStateForWait),
				"value": enum.CentralKitchenForSchoolPackageOrdStateForWait,
			},
			{
				"name":  enum.CentralKitchenForSchoolPackageOrdState.String(enum.CentralKitchenForSchoolPackageOrdStateForSuccess),
				"value": enum.CentralKitchenForSchoolPackageOrdStateForSuccess,
			},
			{
				"name":  enum.CentralKitchenForSchoolPackageOrdState.String(enum.CentralKitchenForSchoolPackageOrdStateForFail),
				"value": enum.CentralKitchenForSchoolPackageOrdStateForFail,
			},
		},
		"ord_state_list": []map[string]interface{}{
			{
				"name":  enum.CentralKitchenForSchoolPackageOrdOrdState.String(enum.CentralKitchenForSchoolPackageOrdOrdStateForWait),
				"value": enum.CentralKitchenForSchoolPackageOrdOrdStateForWait,
			},
			{
				"name":  enum.CentralKitchenForSchoolPackageOrdOrdState.String(enum.CentralKitchenForSchoolPackageOrdOrdStateForSuccess),
				"value": enum.CentralKitchenForSchoolPackageOrdOrdStateForSuccess,
			},
			{
				"name":  enum.CentralKitchenForSchoolPackageOrdOrdState.String(enum.CentralKitchenForSchoolPackageOrdOrdStateForRefunding),
				"value": enum.CentralKitchenForSchoolPackageOrdOrdStateForRefunding,
			},
			{
				"name":  enum.CentralKitchenForSchoolPackageOrdOrdState.String(enum.CentralKitchenForSchoolPackageOrdOrdStateForPartRefunded),
				"value": enum.CentralKitchenForSchoolPackageOrdOrdStateForPartRefunded,
			},
			{
				"name":  enum.CentralKitchenForSchoolPackageOrdOrdState.String(enum.CentralKitchenForSchoolPackageOrdOrdStateForRefunded),
				"value": enum.CentralKitchenForSchoolPackageOrdOrdStateForRefunded,
			},
			{
				"name":  enum.CentralKitchenForSchoolPackageOrdOrdState.String(enum.CentralKitchenForSchoolPackageOrdOrdStateForComplete),
				"value": enum.CentralKitchenForSchoolPackageOrdOrdStateForComplete,
			},
		},
		"user_identity_kind_list": []map[string]interface{}{
			{
				"name":  enum.UserIdentity.String(enum.UserIdentityForCentralKitchenForStudent),
				"value": enum.UserIdentityForCentralKitchenForStudent,
			},
			{
				"name":  enum.UserIdentity.String(enum.UserIdentityForCentralKitchenForTeacher),
				"value": enum.UserIdentityForCentralKitchenForTeacher,
			},
			{
				"name":  enum.UserIdentity.String(enum.UserIdentityForCentralKitchenForWorker),
				"value": enum.UserIdentityForCentralKitchenForWorker,
			},
			{
				"name":  enum.UserIdentity.String(enum.UserIdentityForSelfSupportForStudent),
				"value": enum.UserIdentityForSelfSupportForStudent,
			},
			{
				"name":  enum.UserIdentity.String(enum.UserIdentityForSelfSupportForTeacher),
				"value": enum.UserIdentityForSelfSupportForTeacher,
			},
			{
				"name":  enum.UserIdentity.String(enum.UserIdentityForSelfSupportForWorker),
				"value": enum.UserIdentityForSelfSupportForWorker,
			},
		},
	}, nil)
	return
}

func CentralKitchenForSchoolOrdListExport(c *gin.Context) {
	var req md.CentralKitchenForSchoolOrdListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	if req.StartDate == "" || req.EndDate == "" {
		e.OutErr(c, e.ERR, "查询时间段不能为空")
		return
	}

	resp, _, err := svc2.CentralKitchenForSchoolOrdListExport(c, req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}

	titleList := []string{"订单编号", "支付交易号", "家长电话", "就餐人姓名", "学校名称", "年级", "班级", "报餐类型", "总金额", "支付方式", "支付状态", "创建时间", "订单状态"}
	xlsx := excelize.NewFile()
	xlsx.SetSheetRow("Sheet1", "A1", &titleList)
	style, err := xlsx.NewStyle(`{"fill":{"type":"pattern","color":["FFFF00"],"pattern":1}, "alignment":{"horizontal":"center"}}`)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	xlsx.SetCellStyle("Sheet1", "A1", "M1", style)
	xlsx.SetColWidth("Sheet1", "A", "A", 35)
	xlsx.SetColWidth("Sheet1", "B", "B", 30)
	xlsx.SetColWidth("Sheet1", "C", "E", 15)
	xlsx.SetColWidth("Sheet1", "F", "I", 10)
	xlsx.SetColWidth("Sheet1", "J", "J", 20)
	xlsx.SetColWidth("Sheet1", "K", "K", 10)
	xlsx.SetColWidth("Sheet1", "L", "L", 25)
	xlsx.SetColWidth("Sheet1", "M", "M", 15)
	//表头被第一行用了，只能从第二行开始
	j := 2
	var totalAmount = 0.00
	for _, v := range resp {
		var kind, payWay, payState, orderState string
		switch v.Kind {
		case 1:
			kind = "按学期购买"
			break
		case 2:
			kind = "按月购买"
			break
		case 3:
			kind = "按天购买"
			break
		case 4:
			kind = "补餐"
			break
		}
		switch v.PayWay {
		case 1:
			payWay = "支付宝"
			break
		case 2:
			payWay = "微信"
			break
		}
		switch v.State {
		case 0:
			payState = "待支付"
			break
		case 1:
			payState = "支付成功"
			break
		case 2:
			payState = "支付失败"
			break
		}
		switch v.OrdState {
		case 0:
			orderState = "待支付"
			break
		case 1:
			orderState = "预约成功"
			break
		case 2:
			orderState = "退款中"
			break
		case 3:
			orderState = "部分退款"
			break
		case 4:
			orderState = "已退款"
			break
		case 5:
			orderState = "已完成"
			break
		}
		totalAmount += utils.StrToFloat64(v.TotalPrice)
		xlsx.SetSheetRow("Sheet1", "A"+strconv.Itoa(j), &[]interface{}{
			v.OutTradeNo, v.TradeNo, v.Phone, v.Name, v.EnterpriseName, v.Class, v.Grade,
			kind, utils.StrToFloat64(v.TotalPrice), payWay, payState, v.CreateAt, orderState,
		})
		j++
	}

	xlsx.SetSheetRow("Sheet1", "A"+strconv.Itoa(j), &[]interface{}{"总计：", "-", "-", "-", "-", "-", "-", "-", totalAmount, "-", "-", "-", "-"})

	c.Header("Content-Type", "application/octet-stream")
	c.Header("Content-Disposition", "attachment; filename="+"消费记录"+".xlsx")
	c.Header("Content-Transfer-Encoding", "binary")
	//回写到web 流媒体 形成下载
	_ = xlsx.Write(c.Writer)
	return
}

func CentralKitchenForSchoolReserveList(c *gin.Context) {
	var req md.CentralKitchenForSchoolReserveListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	resp, total, err := svc2.CentralKitchenForSchoolReserveList(c, req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":  resp,
		"total": total,
		"kind_list": []map[string]interface{}{
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayKind.String(enum.CentralKitchenForSchoolUserWithDayKindForBreakfast),
				"value": enum.CentralKitchenForSchoolUserWithDayKindForBreakfast,
			},
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayKind.String(enum.CentralKitchenForSchoolUserWithDayKindForLunch),
				"value": enum.CentralKitchenForSchoolUserWithDayKindForLunch,
			},
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayKind.String(enum.CentralKitchenForSchoolUserWithDayKindForDinner),
				"value": enum.CentralKitchenForSchoolUserWithDayKindForDinner,
			},
		},
		"enterprise_kind_list": md.EnterpriseKindForSchool,
	}, nil)
	return
}

func CentralKitchenForSchoolReserveUpdateStudent(c *gin.Context) {
	if c.Request.Method != "GET" {
		var req md.CentralKitchenForSchoolReserveUpdateStudentReq
		err := c.ShouldBindJSON(&req)
		if err != nil {
			err = validate.HandleValidateErr(err)
			err1 := err.(e.E)
			e.OutErr(c, err1.Code, err1.Error())
			return
		}
		//1、查询对应的 user_identity
		userIdentityDb := db.UserIdentityDb{}
		userIdentityDb.Set(req.Uid)
		identity, err := userIdentityDb.GetUserIdentity(req.UserIdentityId)
		if err != nil {
			e.OutErr(c, e.ERR, err.Error())
			return
		}

		//1、修改 central_kitchen_for_school_package_ord_for_reserve
		centralKitchenForSchoolPackageOrdForReserveDb := db.CentralKitchenForSchoolPackageOrdForReserve{}
		centralKitchenForSchoolPackageOrdForReserveDb.Set("")
		centralKitchenForSchoolPackageOrdForReserve, err := centralKitchenForSchoolPackageOrdForReserveDb.GetCentralKitchenForSchoolPackageOrdForReserveById(req.Id)
		if err != nil {
			e.OutErr(c, e.ERR_DB_ORM, err.Error())
			return
		}
		if centralKitchenForSchoolPackageOrdForReserve == nil {
			e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
			return
		}
		centralKitchenForSchoolPackageOrdForReserve.UserIdentityId = req.UserIdentityId
		centralKitchenForSchoolPackageOrdForReserve.UserIdentityName = identity.Name
		centralKitchenForSchoolPackageOrdForReserve.EnterpriseId = identity.EnterpriseId
		centralKitchenForSchoolPackageOrdForReserve.UpdateAt = time.Now().Format("2006-01-02 15:04:05")
		updateAffected, err := centralKitchenForSchoolPackageOrdForReserveDb.CentralKitchenForSchoolPackageOrdForReserveUpdate(centralKitchenForSchoolPackageOrdForReserve, "enterprise_id", "user_identity_name", "user_identity_id", "update_at")
		if err != nil {
			e.OutErr(c, e.ERR_DB_ORM, err.Error())
			return
		}
		if updateAffected <= 0 {
			e.OutErr(c, e.ERR_DB_ORM, "更新预定记录失败")
			return
		}

		//2、修改 central_kitchen_for_school_user_with_day
		sql := "update central_kitchen_for_school_user_with_day set identity_id = %d where identity_id = %d and kind = %d and date >= '%s' and date <= '%s' and ord_no = '%s'"
		sql = fmt.Sprintf(sql, req.UserIdentityId, req.OriginalUserIdentityId, centralKitchenForSchoolPackageOrdForReserve.Kind, centralKitchenForSchoolPackageOrdForReserve.MealTimeStart,
			centralKitchenForSchoolPackageOrdForReserve.MealTimeEnd, centralKitchenForSchoolPackageOrdForReserve.OutTradeNo)
		fmt.Println("sql >>>>>", sql)
		_, err = db.ExecuteOriginalSql(db.Db, sql)
		if err != nil {
			e.OutErr(c, e.ERR_DB_ORM, err.Error())
			return
		}
		e.OutSuc(c, "success", nil)
		return
	}

	//查询出当前用户下所有身份
	uid := c.DefaultQuery("uid", "")
	userIdentityDb := db.UserIdentityDb{}
	userIdentityDb.Set(utils.StrToInt(uid))
	identity, err := userIdentityDb.FindUserIdentityByKind(enum.UserIdentityForCentralKitchenForStudent)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	var resp []interface{}
	for _, v := range *identity {
		resp = append(resp, map[string]interface{}{
			"name":             v.UserIdentity.Name,
			"enterprise_name":  v.Enterprise.Name,
			"user_identity_id": v.UserIdentity.Id,
		})
	}
	e.OutSuc(c, map[string]interface{}{
		"list": resp,
	}, nil)
	return
}

func CentralKitchenForSchoolReserveDetail(c *gin.Context) {
	id := c.DefaultQuery("id", "")
	centralKitchenForSchoolPackageOrdForReserveDb := db.CentralKitchenForSchoolPackageOrdForReserve{}
	centralKitchenForSchoolPackageOrdForReserveDb.Set("")
	centralKitchenForSchoolPackageOrdForReserve, err := centralKitchenForSchoolPackageOrdForReserveDb.GetCentralKitchenForSchoolPackageOrdForReserveById(utils.StrToInt(id))
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if centralKitchenForSchoolPackageOrdForReserve == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到相应记录")
		return
	}

	var m []*db.CentralKitchenForSchoolUserWithDayWithCentralKitchenForSchoolUserRefundDay
	sess := db.Db
	err = sess.Where("central_kitchen_for_school_user_with_day.ord_no =?", centralKitchenForSchoolPackageOrdForReserve.OutTradeNo).
		And("central_kitchen_for_school_user_with_day.date >=? and central_kitchen_for_school_user_with_day.date <=?", centralKitchenForSchoolPackageOrdForReserve.MealTimeStart, centralKitchenForSchoolPackageOrdForReserve.MealTimeEnd).
		And("central_kitchen_for_school_user_with_day.kind =?", centralKitchenForSchoolPackageOrdForReserve.Kind).
		And("central_kitchen_for_school_user_with_day.identity_id =?", centralKitchenForSchoolPackageOrdForReserve.UserIdentityId).
		Join("LEFT", "central_kitchen_for_school_user_refund_day", "central_kitchen_for_school_user_with_day.id = central_kitchen_for_school_user_refund_day.records_id").
		//Distinct("central_kitchen_for_school_user_with_day.*", "central_kitchen_for_school_user_refund_day.refund_date", "central_kitchen_for_school_user_refund_day.id").
		Asc("central_kitchen_for_school_user_with_day.id").
		Find(&m)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	var resp []map[string]interface{}
	var ishas = map[int]bool{}
	for _, v := range m {
		if ishas[v.CentralKitchenForSchoolUserWithDay.Id] {
			continue
		}
		ishas[v.CentralKitchenForSchoolUserWithDay.Id] = true
		resp = append(resp, map[string]interface{}{
			"id":            v.CentralKitchenForSchoolUserWithDay.Id,
			"ord_no":        v.CentralKitchenForSchoolUserWithDay.OrdNo,
			"uid":           v.CentralKitchenForSchoolUserWithDay.Uid,
			"enterprise_id": v.CentralKitchenForSchoolUserWithDay.EnterpriseId,
			"identity_id":   v.CentralKitchenForSchoolUserWithDay.IdentityId,
			"kind":          v.CentralKitchenForSchoolUserWithDay.Kind,
			"amount":        v.CentralKitchenForSchoolUserWithDay.Amount,
			"date":          v.CentralKitchenForSchoolUserWithDay.Date,
			"state":         v.CentralKitchenForSchoolUserWithDay.State,
			"refund_date":   v.CentralKitchenForSchoolUserRefundDay.RefundDate,
		})
	}
	e.OutSuc(c, map[string]interface{}{
		"list": resp,
		"kind_list": []map[string]interface{}{
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayKind.String(enum.CentralKitchenForSchoolUserWithDayKindForBreakfast),
				"value": enum.CentralKitchenForSchoolUserWithDayKindForBreakfast,
			},
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayKind.String(enum.CentralKitchenForSchoolUserWithDayKindForLunch),
				"value": enum.CentralKitchenForSchoolUserWithDayKindForLunch,
			},
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayKind.String(enum.CentralKitchenForSchoolUserWithDayKindForDinner),
				"value": enum.CentralKitchenForSchoolUserWithDayKindForDinner,
			},
		},
		"state_list": []map[string]interface{}{
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayState.String(enum.CentralKitchenForSchoolUserWithDayStateForWait),
				"value": enum.CentralKitchenForSchoolUserWithDayStateForWait,
			},
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayState.String(enum.CentralKitchenForSchoolUserWithDayStateForAlready),
				"value": enum.CentralKitchenForSchoolUserWithDayStateForAlready,
			},
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayState.String(enum.CentralKitchenForSchoolUserWithDayStateForCanceling),
				"value": enum.CentralKitchenForSchoolUserWithDayStateForCanceling,
			},
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayState.String(enum.CentralKitchenForSchoolUserWithDayStateForCancel),
				"value": enum.CentralKitchenForSchoolUserWithDayStateForCancel,
			},
		},
	}, nil)
	return
}

func CentralKitchenForSchoolOrdRefund(c *gin.Context) {
	//TODO:: 加锁 Redis 锁，防并发
	getString, _ := cache.GetString(md.OrdRefundLockKeyForCentralKitchenSchool)
	if getString != "" {
		e.OutErr(c, e.ERR, "请稍等，存在其他订单退款处理中！")
		return
	}
	cache.Set(md.OrdRefundLockKeyForCentralKitchenSchool, "running")

	var req md.CentralKitchenForSchoolOrdRefundReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		cache.Del(md.OrdRefundLockKeyForCentralKitchenSchool)
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		cache.Del(md.OrdRefundLockKeyForCentralKitchenSchool)
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		cache.Del(md.OrdRefundLockKeyForCentralKitchenSchool)
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}
	err = svc2.CentralKitchenForSchoolOrdRefund(req)
	if err != nil {
		cache.Del(md.OrdRefundLockKeyForCentralKitchenSchool)
		e.OutErr(c, e.ERR, err.Error())
		return
	}

	cache.Del(md.OrdRefundLockKeyForCentralKitchenSchool)
	e.OutSuc(c, "success", nil)
	return
}

func SelfSupportForSchoolOrdRefund(c *gin.Context) {
	var req md.SelfSupportForSchoolOrdRefundReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	err = svc2.SelfSupportForSchoolOrdRefund(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func SelfSupportForSchoolOrdPartRefund(c *gin.Context) {
	var req md.SelfSupportForSchoolOrdPartRefundReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	err = svc2.SelfSupportForSchoolOrdPartRefund(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func CentralKitchenForSchoolBatchAskForLeave(c *gin.Context) {
	//TODO:: 加锁 Redis 锁，防并发
	getString, _ := cache.GetString(md.BatchAskForLeaveLockKeyForCentralKitchen)
	if getString != "" {
		e.OutErr(c, e.ERR, "请稍等，存在其他请假处理中！")
		return
	}
	cache.Set(md.BatchAskForLeaveLockKeyForCentralKitchen, "running")
	utils.FilePutContents("DealCentralKitchenForSchoolBatchAskForLeave", "批量请假处理，开始时间:::"+time.Now().Format("2006-01-02 15:04:05"))

	Kind := c.DefaultQuery("kind", "1")
	switch Kind {
	case "1":
		//按学校
		var req md.CentralKitchenForSchoolBatchAskForLeaveReqBySchool
		err := c.ShouldBindJSON(&req)
		if err != nil {
			cache.Del(md.BatchAskForLeaveLockKeyForCentralKitchen)
			err = validate.HandleValidateErr(err)
			err1 := err.(e.E)
			e.OutErr(c, err1.Code, err1.Error())
			return
		}
		var datesMap = map[string]string{}
		for _, v := range req.Dates {
			datesMap[v] = v
		}
		var dates []string
		for _, v := range datesMap {
			dates = append(dates, v)
		}
		req.Dates = dates

		err = svc2.CentralKitchenForSchoolBatchAskForLeaveBySchool(req)
		if err != nil {
			cache.Del(md.BatchAskForLeaveLockKeyForCentralKitchen)
			e.OutErr(c, e.ERR, err.Error())
			return
		}
		break
	case "2":
		//按年级
		var req md.CentralKitchenForSchoolBatchAskForLeaveReqByGrade
		err := c.ShouldBindJSON(&req)
		if err != nil {
			cache.Del(md.BatchAskForLeaveLockKeyForCentralKitchen)
			err = validate.HandleValidateErr(err)
			err1 := err.(e.E)
			e.OutErr(c, err1.Code, err1.Error())
			return
		}
		var datesMap = map[string]string{}
		for _, v := range req.Dates {
			datesMap[v] = v
		}
		var dates []string
		for _, v := range datesMap {
			dates = append(dates, v)
		}
		req.Dates = dates

		err = svc2.CentralKitchenForSchoolBatchAskForLeaveByGrade(req)
		if err != nil {
			cache.Del(md.BatchAskForLeaveLockKeyForCentralKitchen)
			e.OutErr(c, e.ERR, err.Error())
			return
		}
		break
	case "3":
		//按班级
		var req md.CentralKitchenForSchoolBatchAskForLeaveReqByClass
		err := c.ShouldBindJSON(&req)
		if err != nil {
			cache.Del(md.BatchAskForLeaveLockKeyForCentralKitchen)
			err = validate.HandleValidateErr(err)
			err1 := err.(e.E)
			e.OutErr(c, err1.Code, err1.Error())
			return
		}
		var datesMap = map[string]string{}
		for _, v := range req.Dates {
			datesMap[v] = v
		}
		var dates []string
		for _, v := range datesMap {
			dates = append(dates, v)
		}
		req.Dates = dates

		err = svc2.CentralKitchenForSchoolBatchAskForLeaveByClass(req)
		if err != nil {
			cache.Del(md.BatchAskForLeaveLockKeyForCentralKitchen)
			e.OutErr(c, e.ERR, err.Error())
			return
		}
		break
	}

	cache.Del(md.BatchAskForLeaveLockKeyForCentralKitchen)
	e.OutSuc(c, "success", nil)
	return
}

func CentralKitchenForSchoolOrdDetail(c *gin.Context) {
	outTradeNo := c.DefaultQuery("out_trade_no", "")
	centralKitchenForSchoolPackageOrd := db.CentralKitchenForSchoolPackageOrd{}
	centralKitchenForSchoolPackageOrd.Set(outTradeNo)
	ord, err := centralKitchenForSchoolPackageOrd.GetCentralKitchenForSchoolPackageOrd()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if ord == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应订单记录")
		return
	}
	centralKitchenForSchoolUserWithDayDb := db.CentralKitchenForSchoolUserWithDayDb{}
	centralKitchenForSchoolUserWithDayDb.Set(0)
	list, err := centralKitchenForSchoolUserWithDayDb.FindCentralKitchenForSchoolUserWithDayByOrdNo(ord.OutTradeNo)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	e.OutSuc(c, map[string]interface{}{
		"list": list,
		"kind_list": []map[string]interface{}{
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayKind.String(enum.CentralKitchenForSchoolUserWithDayKindForBreakfast),
				"value": enum.CentralKitchenForSchoolUserWithDayKindForBreakfast,
			},
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayKind.String(enum.CentralKitchenForSchoolUserWithDayKindForLunch),
				"value": enum.CentralKitchenForSchoolUserWithDayKindForLunch,
			},
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayKind.String(enum.CentralKitchenForSchoolUserWithDayKindForDinner),
				"value": enum.CentralKitchenForSchoolUserWithDayKindForDinner,
			},
		},
		"state_list": []map[string]interface{}{
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayState.String(enum.CentralKitchenForSchoolUserWithDayStateForWait),
				"value": enum.CentralKitchenForSchoolUserWithDayStateForWait,
			},
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayState.String(enum.CentralKitchenForSchoolUserWithDayStateForAlready),
				"value": enum.CentralKitchenForSchoolUserWithDayStateForAlready,
			},
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayState.String(enum.CentralKitchenForSchoolUserWithDayStateForCanceling),
				"value": enum.CentralKitchenForSchoolUserWithDayStateForCanceling,
			},
			{
				"name":  enum.CentralKitchenForSchoolUserWithDayState.String(enum.CentralKitchenForSchoolUserWithDayStateForCancel),
				"value": enum.CentralKitchenForSchoolUserWithDayStateForCancel,
			},
		},
	}, nil)
	return
}

func CentralKitchenForSchoolPeriodList(c *gin.Context) {
	var req md.CentralKitchenForSchoolPeriodListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	resp, total, err := svc2.CentralKitchenForSchoolPeriodList(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":  resp,
		"total": total,
	}, nil)
	return
}

func CentralKitchenForSchoolGradeList(c *gin.Context) {
	var req md.CentralKitchenForSchoolGradeListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	resp, total, err := svc2.CentralKitchenForSchoolGradeList(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":  resp,
		"total": total,
	}, nil)
	return
}

func CentralKitchenForSchoolClassList(c *gin.Context) {
	var req md.CentralKitchenForSchoolClassListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	resp, total, err := svc2.CentralKitchenForSchoolClassList(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":  resp,
		"total": total,
	}, nil)
	return
}

type CentralKitchenForSchoolClassSortArgs struct {
	Ids   []int `json:"ids" binding:"required"`
	Page  int   `json:"page" binding:"required"`
	Limit int   `json:"limit" binding:"required"`
}

func CentralKitchenForSchoolClassSort(c *gin.Context) {
	var ClassSortArgs CentralKitchenForSchoolClassSortArgs
	if err := c.ShouldBindJSON(&ClassSortArgs); err != nil {
		e.OutErr(c, e.ERR_INVALID_ARGS, err)
		return
	}
	classDb := db.ClassDb{}
	classDb.Set(0)
	class, err := classDb.FindClassById(ClassSortArgs.Ids)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	for k, v := range *class {
		v.Sort = (ClassSortArgs.Page-1)*ClassSortArgs.Limit + (1000 - k)
		_, err1 := classDb.ClassUpdate(&v, "sort")
		if err1 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err1.Error())
			return
		}
	}
	e.OutSuc(c, "success", nil)
}

func CentralKitchenForSchoolGradeDelete(c *gin.Context) {
	gradeId := c.Param("id")
	//1、查找当前年级
	gradeDb := db.GradeDb{}
	gradeDb.Set(0)
	grade, err := gradeDb.GetGrade(utils.StrToInt(gradeId))
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	//2、查找当前年级下是否还包含班级
	classDb := db.ClassDb{}
	classDb.Set(grade.Id)
	class, err := classDb.FindClass()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if len(*class) > 0 {
		e.OutErr(c, e.ERR, "当前年级下存在未删除的班级!")
		return
	}
	_, err = gradeDb.GradeDeleteBySession(grade.Id)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func CentralKitchenForSchoolPeriodDelete(c *gin.Context) {
	periodId := c.Param("id")
	//1、查找当前学段
	periodDb := db.PeriodDb{}
	periodDb.Set(0)
	period, err := periodDb.GetPeriod(utils.StrToInt(periodId))
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	//2、查找当前年级下是否还包含年级
	gradeDb := db.GradeDb{}
	gradeDb.Set(0)
	grade, err := gradeDb.FindGradeByPeriodId(utils.StrToInt(periodId))
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if len(*grade) > 0 {
		e.OutErr(c, e.ERR, "当前学段下存在未删除的年级!")
		return
	}
	_, err = periodDb.PeriodDeleteBySession(period.Id)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func CentralKitchenForSchoolClassDelete(c *gin.Context) {
	classId := c.Param("id")
	classWithUserDb := db.ClassWithUserDb{}

	//1、查找当前年级
	classDb := db.ClassDb{}
	classDb.Set(0)
	class, err := classDb.GetClass(utils.StrToInt(classId))
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	_, err = classDb.ClassDeleteBySession(class.Id)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	//2、删除当前班级下的所有关联学生
	classWithUserDb.Set()
	_, err = classWithUserDb.DeleteClassWithUserByClass(classId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func CentralKitchenForSchoolClassDeleteCheck(c *gin.Context) {
	classId := c.Param("id")
	classWithUserDb := db.ClassWithUserDb{}
	classWithUserDb.Set()
	classWithUsers, err := classWithUserDb.FindUserIdentity(classId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	var isHasStudent = false
	if len(*classWithUsers) > 0 {
		isHasStudent = true
	}

	e.OutSuc(c, map[string]interface{}{
		"is_has_student": isHasStudent,
	}, nil)
	return
}

func CentralKitchenForSchoolWxTransferOrdList(c *gin.Context) {
	var req md.CentralKitchenForSchoolWxTransferOrdListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	centralKitchenWxTransferOrdDb := db.CentralKitchenWxTransferOrd{}
	centralKitchenWxTransferOrdDb.Set("")
	list, total, err := centralKitchenWxTransferOrdDb.FindCentralKitchenWxTransferOrd(req.Page, req.Limit)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}

	e.OutSuc(c, map[string]interface{}{
		"list":       list,
		"total":      total,
		"state_list": md.CentralKitchenWxTransferOrdForState,
	}, nil)
	return
}

func CentralKitchenForSchoolWxTransfer(c *gin.Context) {
	var req md.CentralKitchenForSchoolWxTransferReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	uDb := db.UserDb{}
	uDb.Set()
	outTradeNo := utils.OrderUUID(int(time.Now().Unix()))
	sysCfgDb := db.SysCfgDb{}
	sysCfgDb.Set()
	sysCfg := sysCfgDb.SysCfgFindWithDb(enum.WxAppletAppId)
	appid := sysCfg[enum.WxAppletAppId]
	now := time.Now()
	var centralKitchenWxTransferOrdData *model.CentralKitchenWxTransferOrd
	var centralKitchenWxTransferOrdListData []*model.CentralKitchenWxTransferOrdList
	var totalAmount float64
	for key, uid := range req.Uids {
		user, err := uDb.GetUser(uid)
		if err != nil {
			e.OutErr(c, e.ERR_DB_ORM, err.Error())
			return
		}
		if user == nil {
			e.OutErr(c, e.ERR_NOT_FAN, "未查询到相关用户")
			return
		}
		if user.OpenId == "" {
			e.OutErr(c, e.ERR_NOT_FAN, "当前用户openid为空")
			return
		}
		totalAmount += utils.StrToFloat64(req.Amount)
		centralKitchenWxTransferOrdListData = append(centralKitchenWxTransferOrdListData, &model.CentralKitchenWxTransferOrdList{
			Uid:            user.Id,
			OutTradeNo:     outTradeNo,
			OutDetailNo:    outTradeNo + "_" + utils.IntToStr(key),
			TransferRemark: "智盛-央厨转账",
			TransferAmount: req.Amount,
			Openid:         user.OpenId,
			CreateAt:       now.Format("2006-01-02 15:04:05"),
			UpdateAt:       now.Format("2006-01-02 15:04:05"),
		})
	}
	if totalAmount > 200 {
		e.OutErr(c, e.ERR, "总计转账金额超过200元上限")
		return
	}

	centralKitchenWxTransferOrdData = &model.CentralKitchenWxTransferOrd{
		Appid:       appid,
		OutTradeNo:  outTradeNo,
		BatchName:   "智盛-央厨转账",
		BatchRemark: req.BatchRemark,
		TotalAmount: req.Amount,
		TotalNum:    len(req.Uids),
		State:       1,
		Msg:         "",
		CreateAt:    now.Format("2006-01-02 15:04:05"),
		UpdateAt:    now.Format("2006-01-02 15:04:05"),
	}

	session := db.Db.NewSession()
	defer session.Close()
	session.Begin()

	centralKitchenWxTransferOrdDb := db.CentralKitchenWxTransferOrd{}
	centralKitchenWxTransferOrdDb.Set("")
	_, err = centralKitchenWxTransferOrdDb.CentralKitchenWxTransferOrdInsertBySession(session, centralKitchenWxTransferOrdData)
	if err != nil {
		session.Rollback()
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	centralKitchenWxTransferOrdListDb := db.CentralKitchenWxTransferOrdList{}
	centralKitchenWxTransferOrdListDb.Set("")
	_, err = centralKitchenWxTransferOrdListDb.BatchAddCentralKitchenWxTransferOrdListBySession(session, centralKitchenWxTransferOrdListData)
	if err != nil {
		session.Rollback()
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	e.OutSuc(c, "success", nil)
	return
}

func CentralKitchenForSchoolWxTransferOrdFlow(c *gin.Context) {
	outTradeNo := c.DefaultQuery("out_trade_no", "")

	centralKitchenWxTransferOrdDb := db.CentralKitchenWxTransferOrd{}
	centralKitchenWxTransferOrdDb.Set(outTradeNo)
	resp, err := centralKitchenWxTransferOrdDb.GetCentralKitchenWxTransferOrd()
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}

	e.OutSuc(c, map[string]interface{}{
		"data":       resp,
		"state_list": md.CentralKitchenWxTransferOrdForState,
	}, nil)
	return
}
